API
===

.. automodule:: coniql
    :members:

    ``coniql``
    -----------------------------------

This is the internal API reference for coniql

.. data:: coniql.__version__
    :type: str

    Version number as calculated by https://github.com/dls-controls/versiongit
